@@ -546,6 +546,13 @@ class fillVars(object, cl_base.glob_attr):
             return ", ".join(map(lambda x: '"'+x+'"', jabberHosts.split(",")))
         return ""
 
+    def get_sr_jabber_hosts_yml(self):
+        """Текст в ejabberd.cfg - имена хостов с которыми работает сервис"""
+        jabberHosts = self.Get("sr_jabber_hosts")
+        if jabberHosts:
+            return "\n".join(map(lambda x: '  - "%s"' % x, jabberHosts.split(",")))
+        return ""
+
     def get_sr_jabber_user_name(self):
         """Имя jabber пользователя (левая часть jabber id)"""
         userJid = self.Get("sr_jabber_user_id")
